@@ -31,6 +31,7 @@ sub run {
         _https_info => undef,
         _connection => {
             input_handle  => IO::Scalar->new( \( $request->content ) ),
+            env           => ($args{env} || {}),
         },
         %args,
     );
@@ -54,12 +55,13 @@ HTTP::Engine::Interface::Test - HTTP::Engine Test Interface
   my $response = HTTP::Engine->new(
       interface => {
           module => 'Test',
+          request_handler => sub {
+              my $req = shift;
+              HTTP::Engine::Response->new( body => Dumper($req) );
+          }
       },
-      request_handler => sub {
-          my $req = shift;
-          HTTP::Engine::Response->new( body => Dumper($req) );
-      }
-  )->run(HTTP::Request->new( GET => 'http://localhost/'), \%ENV);
+  )->run(HTTP::Request->new( GET => 'http://localhost/' ), env => \%ENV);
+  print $response->content;
 
 =head1 DESCRIPTION
 
