@@ -1,10 +1,10 @@
 package HTTP::Engine::RequestBuilder::CGI;
-use Shika;
+use Mouse;
 
-with qw(
-    HTTP::Engine::Role::RequestBuilder
-    HTTP::Engine::Role::RequestBuilder::ParseEnv
+with $_ for qw(
     HTTP::Engine::Role::RequestBuilder::HTTPBody
+    HTTP::Engine::Role::RequestBuilder::ParseEnv
+    HTTP::Engine::Role::RequestBuilder
 );
 
 __PACKAGE__
