@@ -1,11 +1,11 @@
 package HTTP::Engine::RequestBuilder::NoEnv;
-use Shika;
+use Mouse;
 
-with qw(
-    HTTP::Engine::Role::RequestBuilder
+with $_ for qw(
     HTTP::Engine::Role::RequestBuilder::Standard
     HTTP::Engine::Role::RequestBuilder::HTTPBody
     HTTP::Engine::Role::RequestBuilder::NoEnv
+    HTTP::Engine::Role::RequestBuilder
 );
 
-__PACKAGE__
+1;
