@@ -1,11 +1,12 @@
 #!/usr/bin/perl
 
 package HTTP::Engine::Role::RequestBuilder::HTTPBody;
-use Shika::Role;
+use Mouse::Role;
 
 with qw(
     HTTP::Engine::Role::RequestBuilder::ReadBody
 );
+use HTTP::Body;
 
 # tempolary file path for upload file.
 has upload_tmp => (
@@ -41,7 +42,6 @@ sub _build_read_state {
     my $length = $req->content_length || 0;
     my $type   = $req->header('Content-Type');
 
-    HTTP::Engine::Util::require_once('HTTP/Body.pm');
     my $body = HTTP::Body->new($type, $length);
     $body->tmpdir( $self->upload_tmp) if $self->upload_tmp;
 
